import Vue from 'vue'
import Element from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import i18n from './lang' // 国际化
import App from './App'
import router from './router'
import store from './store'
import * as filters from './filters' // 全局filter
import './icons' // icon
import './errorLog'// error log
import './permission' // 权限
import '@/hdcom' // 权限
import axios from 'axios'
import schema from 'async-validator'


window.schema = schema //校验
Vue.prototype.$http = axios
Vue.use(Element, {
  i18n: (key, value) => i18n.t(key, value)
})

// register global utility filters.
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})
//Vue.prototype.$utils=utils
Vue.config.productionTip = false

let myVue = new Vue({
  el: '#app',
  router,
  store,
  i18n,
  template: '<App/>',
  components: {App}
})
axios.interceptors.request.use(
  config => {
    if (!config.data) {
      config.data = {}
    }
    if (myVue.$route) {
      config.headers.mainMenuId = myVue.$route.name//权限用,设置当前menuId
    }
    if (myVue.$store && myVue.$store.getters && myVue.$store.getters.token) {
      config.headers.hdTokenId = myVue.$store.getters.token//权限用,设置当前toekn
    }
    return config;
  },
  err => {
    return Promise.reject(err);
  });
axios.interceptors.response.use(
  response => {
    if (-999 == response.data) {//无权限的跳到登录页
      myVue.$store.dispatch('LogOut').then(() => {
        location.reload()// 为了重新实例化vue-router对象 避免bug
      })
    }
    return response
  },
  error => {
    console.error("请求后台数据出错,给对象附的值会变成字符串,属于常见问题")
    if (error && error.response && error.response.data) {
      myVue.$message({
        type: 'error',
        message: error.response.data.path + "---" + error.response.data.status
      })
    }
    return Promise.reject(error)
  });



